@@ -35,8 +35,8 @@ var nameRestCharRegexp = regexp.MustCompile("^" + nameRestCharRegexpPattern + "$
 
 var NameRegexpPattern = nameFirstCharRegexpPattern + nameRestCharRegexpPattern
 
-const nameFirstCharRegexpPattern = "[A-Za-z_.]"
-const nameRestCharRegexpPattern = `[A-Za-z0-9_.-]*`
+const nameFirstCharRegexpPattern = "[A-Za-z0-9_.-]"
+const nameRestCharRegexpPattern = "[A-Za-z0-9_.-]*"
 
 // IsName checks whether a string is a legal Name.
 func IsName(s string) bool {
@@ -61,7 +61,7 @@ const QNameDelimiter = "/"
 var QNameRegexp = regexp.MustCompile(QNameRegexpPattern)
 var QNameRegexpPattern = "(" + NameRegexpPattern + "\\" + QNameDelimiter + ")*" + NameRegexpPattern
 
-// IsQName checks whether a string is a legal Name.
+// IsQName checks whether a string is a legal QName.
 func IsQName(s string) bool {
 	return s != "" && QNameRegexp.FindString(s) == s
 }
